### COMMANDS FOR AN OBVIOUS IMPLEMENTATION THE INTENDED GOAL
Your job is now:
* remember you are strictly following your given RULES AS EXPERT PYTHON DEVELOPER for code and architectural code quality
* change only code that must changed
* Now implement the intended goal and return the code in blocks not smaller than a method and in the following format 
```python
# [ ] extract
# filename: {/path/filename}.py
{python code}
```

* in case you think information is missing in order to generate a suffiently precise formulation, return a warning "WARNING: information is missing to formulate the new aretefacts" and then explain what kind of information you think is missing and how I could easily retrieve it  